@@ -2538,7 +2538,6 @@ StrBuf *StrBufSanitizeEmailRecipientVector(const StrBuf *Recp,
 				pch = NULL;
 				if (EmailEnd != NULL) {
 					gt = 1;
-					EmailEnd --;
 				}
 				else {
 					EmailEnd = pche;
@@ -2564,7 +2563,11 @@ StrBuf *StrBufSanitizeEmailRecipientVector(const StrBuf *Recp,
 				EmailStart = strchr(UserStart, '<');
 				if ((EmailStart == NULL) || (EmailStart > EmailEnd))
 					break;
-				UserEnd = EmailStart - 1;
+				UserEnd = EmailStart;
+
+				while ((UserEnd > UserStart) && 
+				       isspace (*(UserEnd - 1)))
+					UserEnd --;
 				EmailStart ++;
 				if (UserStart >= UserEnd)
 					UserStart = UserEnd = NULL;
@@ -2847,6 +2850,8 @@ inline static void DecodeSegment(StrBuf *Target,
 	
 	*encoding = toupper(*encoding);
 	if (*encoding == 'B') {	/**< base64 */
+		if (ConvertBuf2->BufSize < ConvertBuf->BufUsed)
+			IncreaseBuf(ConvertBuf2, 0, ConvertBuf->BufUsed);
 		ConvertBuf2->BufUsed = CtdlDecodeBase64(ConvertBuf2->buf, 
 							ConvertBuf->buf, 
 							ConvertBuf->BufUsed);
@@ -2862,6 +2867,9 @@ inline static void DecodeSegment(StrBuf *Target,
 			pos++;
 		}
 		
+		if (ConvertBuf2->BufSize < ConvertBuf->BufUsed)
+			IncreaseBuf(ConvertBuf2, 0, ConvertBuf->BufUsed);
+
 		ConvertBuf2->BufUsed = CtdlDecodeQuotedPrintable(
 			ConvertBuf2->buf, 
 			ConvertBuf->buf,
